@@ -2,29 +2,26 @@ from typing import TypeVar, Type, Generic, Optional, Callable
 
 from pyteamtv.infra.requester import Requester
 
-T = TypeVar('T')
+T = TypeVar("T")
 
 
 class List(Generic[T]):
-    def __init__(self,
-                 content_class: Type[T],
-                 requester: Requester,
-                 method: str,
-                 url: str,
-                 item_filter: Optional[Callable[[T], bool]] = None):
+    def __init__(
+        self,
+        content_class: Type[T],
+        requester: Requester,
+        method: str,
+        url: str,
+        item_filter: Optional[Callable[[T], bool]] = None,
+    ):
         self.requester = requester
         self.content_class = content_class
         self.url = url
 
         data = requester.request(method, url)
-        items = [content_class(
-            requester,
-            item
-        ) for item in data]
+        items = [content_class(requester, item) for item in data]
         if item_filter:
-            self._items = [
-                item for item in items if item_filter(item)
-            ]
+            self._items = [item for item in items if item_filter(item)]
         else:
             self._items = items
 
@@ -36,6 +33,11 @@ class List(Generic[T]):
         for item in self._items:
             yield item
 
+    def find_by(self, fn: Callable[[T], bool]) -> Optional[T]:
+        for item in self:
+            if fn(item):
+                return item
+
     # TODO: not used yet, might be usefull
     # when /api/sportingEvent/<uuid>/videos endpoint exists
     # def create(self, body) -> T:
@@ -50,5 +52,5 @@ class List(Generic[T]):
     def __repr__(self):
         return str(self._items)
 
-
-
+    def __bool__(self):
+        return len(self._items) > 0
