@@ -3,6 +3,7 @@ import os
 from datetime import datetime
 from typing import Optional, Union
 
+from .bulk_observation import BulkObservation
 from .event_stream import EventStream
 from .line_up import LineUp
 from .list import List
@@ -115,6 +116,14 @@ class SportingEvent(TeamTVObject):
     def is_local(self):
         return self._is_local
 
+    @property
+    def home_team_id(self):
+        return self._home_team_id
+
+    @property
+    def away_team_id(self):
+        return self._away_team_id
+
     def get_clock(self, id_: str) -> Optional[Clock]:
         if id_ not in self._clocks:
             for key, clock in self._clocks.items():
@@ -129,12 +138,17 @@ class SportingEvent(TeamTVObject):
             {"sportingEventId": self.sporting_event_id, **self._clocks[id_]},
         )
 
-    def get_observation_log(self) -> ObservationLog:
-        video_id = self.main_video_id
-        if video_id:
-            clock_id = self._clocks[video_id]["clockId"]
-        else:
-            clock_id = "U1"
+    def get_observation_log(
+        self, video_id: str = None, clock_id: str = None
+    ) -> ObservationLog:
+        if not clock_id:
+            if not video_id:
+                video_id = self.main_video_id
+
+            if video_id:
+                clock_id = self._clocks[video_id]["clockId"]
+            else:
+                clock_id = "U1"
 
         return ObservationLog(
             Observation,
@@ -145,6 +159,27 @@ class SportingEvent(TeamTVObject):
             self,
         )
 
+    def get_team(self, team_id: str) -> dict:
+        home_team_name, away_team_name = self.name.split(" - ")
+        if team_id == self.home_team_id:
+            return {
+                'name': home_team_name,
+                'teamId': team_id,
+                'ground': 'home'
+            }
+        elif team_id == self.away_team_id:
+            return {
+                'name': away_team_name,
+                'teamId': team_id,
+                'ground': 'away'
+            }
+        else:
+            return {
+                'name': None,
+                'teamId': None,
+                'ground': None
+            }
+
     def add_bulk_observation(
         self, observations: List[DictObservation], description: Optional[str] = None
     ):
@@ -163,6 +198,32 @@ class SportingEvent(TeamTVObject):
             "POST", path, {"observations": observations, "description": description}
         )
 
+    def get_bulk_observations(self) -> List[BulkObservation]:
+        return List(
+            BulkObservation,
+            self._requester,
+            "GET",
+            f"/sportingEvents/{self.sporting_event_id}/bulkObservations",
+        )
+
+    def delete_bulk_observation(self, bulk_observation_id):
+        path = (
+            f"/sportingEvents/{self.sporting_event_id}/"
+            f"bulkObservations/{bulk_observation_id}"
+        )
+        self._requester.request("DELETE", path)
+
+    def upsert_bulk_observations(
+        self, observations: List[DictObservation], description: str
+    ):
+        bulk_observations = self.get_bulk_observations()
+        for bulk_observation in bulk_observations:
+            if bulk_observation.description == description:
+                self.delete_bulk_observation(bulk_observation.bulk_observation_id)
+                break
+
+        self.add_bulk_observation(observations, description)
+
     def get_videos(self) -> List[Video]:
         def _filter(video: Video) -> bool:
             return video.video_id in self._video_ids
@@ -251,6 +312,8 @@ class SportingEvent(TeamTVObject):
             attributes["scheduledAt"].replace("Z", "+00:00")
         )
         self._is_local = attributes["_metadata"]["source"]["type"] == "ResourceGroup"
+        self._home_team_id = attributes['homeTeamId']
+        self._away_team_id = attributes['awayTeamId']
 
     def __str__(self):
         return f"{self._scheduled_at.strftime('%d/%m/%y')} {self._name}"
